# -*- coding: utf-8 -*-
from setuphelpers import *
import json


def update_package():
    # Declaring local variables
    package_updated = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    api_url = "https://api.github.com/repos/PowerShell/PowerShell/releases"
    arch_dict = {"x64": "-win-x64.msi", "x86": "-win-x86.msi"}

    # Getting latest version information from official sources
    print("API used is: %s" % api_url)
    dict_result = json.loads(wgets(api_url, proxies=proxies))
    for tag in dict_result:
        if tag["tag_name"] == "v7.2.7":
            print("Tag URL used is: %s" % tag["html_url"])
            version = tag["tag_name"].split("-")[-1].replace("v", "")
            for download in tag["assets"]:
                if arch_dict[control.architecture] in download["name"]:
                    download_url = download["browser_download_url"]
                    latest_bin = download["name"]
                    break
            break

    # Downloading latest binaries
    print("Latest %s version is: %s" % (control.name, version))
    print("Download URL is: %s" % download_url)
    if not isfile(latest_bin):
        print("Downloading: %s" % latest_bin)
        wget(download_url, latest_bin, proxies=proxies)
    else:
        print("Binary is present: %s" % latest_bin)

    # Checking version from file
    version_from_file = get_version_from_binary(latest_bin)
    if Version(version_from_file, 4) != Version(version, 4) and version_from_file != "":
        print("Changing version to the version number of the binary")
        # os.rename(latest_bin, latest_bin.replace(version, version_from_file))
        version = version_from_file
    else:
        print("Binary file version corresponds to online version")

    # Changing version of the package
    if Version(version, 4) > Version(control.get_software_version(), 4):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        package_updated = True
    else:
        print("Software version up-to-date (%s)" % Version(version))
    control.set_software_version(version)
    control.save_control_to_wapt()

    # Deleting outdated binaries
    remove_outdated_binaries(version)

    # Validating update-package-sources
    return package_updated
